# Code from PythonProgramming.net

# Create a color tuple and complete the GL_QUADS function 

# Import pygame and OpenGL libraries

import pygame
from pygame.locals import *

from OpenGL.GL import *
from OpenGL.GLU import *

vertices = (    # Define eight (8) cuve vertices
    (1, -1, -1),
    (1, 1, -1),
    (-1, 1, -1),
    (-1, -1, -1),
    (1, -1, 1),
    (1, 1, 1),
    (-1, -1, 1),
    (-1, 1, 1)
    )

edges = (   # Define twelve (12) cube edges. The numbers are vertex indices.
    (0,1),
    (0,3),
    (0,4),
    (2,1),
    (2,3),
    (2,7),
    (6,3),
    (6,4),
    (6,7),
    (5,1),
    (5,4),
    (5,7)
    )

# Add a new tuple consisting of a bunch of RGB colors (r,g,b)
# Go ahead and make all possible permutations of (r,g,b) where 
# r,g,b = 0 or 1 and duplicate the list a few times to get 12~15 entries

# These surfaces are composed of 4 vertex indices on each cube face.
# The numbers in the surfaces tuple are actually
# indices to the vertex array defined above. If you think hard enough, 
# ou can imagine the square each set of 4 coordinates makes. 

surfaces = (             
    (0,1,2,3),
    (3,2,7,6),
    (6,7,5,4),
    (4,5,1,0),
    (1,5,7,2),
    (4,0,3,6)
    )


def Cube():
    glBegin(GL_QUADS) # begin OpenGL commands

    # rewrite below pseudocode into real Python

    # iterate through all surfaces
    # set initial color index = 0
    # iterate through vertex indices in surface
    # iterate color index
    # use glColor3fv() and pass it the color array value
    # use glVertex3fv() and pass it the current vertex array value

    glEnd() # end OpenGL commands

    # Extra challenge: Try changing the color of the cube!

    glBegin(GL_LINES) # begin OpenGL commands
    for edge in edges:  # iterate through edges
        for vertex in edge:  # iterate thru vertices
            glVertex3fv(vertices[vertex])  # draw lines using vertices
            # This ends up looking like this:
            # glVertex3fv((1, -1, -1))
            # glVertex3fv((1, 1, -1))
            # glVertex3fv((-1, 1, -1))
    glEnd() # end OpenGL commands


def main():
    pygame.init() # start PyGame framework
    display = (800,600)
    # Set display to use OpenGL and two buffers for smooth animation
    pygame.display.set_mode(display, DOUBLEBUF|OPENGL) 

    # Set up perspective. Parameter List:
    # 1. Field of View (FOV) in degrees
    # 2. Aspect ratio
    # 3. and 4. Clipping planes (min and max viewable Z distances)
    gluPerspective(45, (display[0]/display[1]), 0.1, 50.0)

    # Move viewpoint (your eyes) backwards 5 units
    glTranslatef(0.0,0.0, -5)

    # Event loop-- checks for [X]-ing out the window
    while True:
        for event in pygame.event.get():
            if event.type == pygame.QUIT:
                pygame.quit()
                quit()

        # Rotate current space (angle, x, y, z)
        # Try changing the values here to make the cube move differently!
        glRotatef(1, 3, 2, 2)
        # Clear buffer (erasing the canvas)
        glClear(GL_COLOR_BUFFER_BIT|GL_DEPTH_BUFFER_BIT)
        # Draw the cube again (remember, we just rotated space)
        Cube()
        # Update display
        pygame.display.flip()
        # Small delay
        pygame.time.wait(10)


main()